JsonDialogThemeBuilderModel class
Creates a dialog theme that can be used for ThemeData.dialogTheme.
- Inheritance
-
- Object
- JsonClass
- JsonWidgetBuilderModel
- JsonDialogThemeBuilderModel
Constructors
-
JsonDialogThemeBuilderModel(Map<
String, dynamic> args, {EdgeInsetsGeometry? actionsPadding, AlignmentGeometry? alignment, Color? backgroundColor, Color? barrierColor, Clip? clipBehavior, TextStyle? contentTextStyle, DialogThemeData? data, double? elevation, Color? iconColor, EdgeInsets? insetPadding, Color? shadowColor, ShapeBorder? shape, Color? surfaceTintColor, TextStyle? titleTextStyle, JsonWidgetData? child}) -
const
Properties
- actionsPadding → EdgeInsetsGeometry?
-
final
- alignment → AlignmentGeometry?
-
final
-
args
→ Map<
String, dynamic> -
finalinherited
- backgroundColor → Color?
-
final
- barrierColor → Color?
-
final
- child → JsonWidgetData?
-
final
- clipBehavior → Clip?
-
final
- contentTextStyle → TextStyle?
-
final
- data → DialogThemeData?
-
final
- elevation → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconColor → Color?
-
final
- insetPadding → EdgeInsets?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowColor → Color?
-
final
- shape → ShapeBorder?
-
final
- surfaceTintColor → Color?
-
final
- titleTextStyle → TextStyle?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Abstract function that concrete classes must implement. This must encode
the internal data model to a JSON compatible representation.
override
-
toString(
) → String -
Returns the string encoded JSON representation for this class. This will
remove all null values and empty collections from the returned string.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromDynamic(
dynamic map, {Map< String, dynamic> args = const {}, JsonWidgetRegistry? registry}) → JsonDialogThemeBuilderModel -
maybeFromDynamic(
dynamic map, {Map< String, dynamic> args = const {}, JsonWidgetRegistry? registry}) → JsonDialogThemeBuilderModel?